@@ -22,19 +22,20 @@ Sonarr plugin general settings configuration.
 from __future__ import annotations
 
 from ipaddress import IPv4Address
-from typing import Any, Dict, List, Literal, Mapping, Optional, Tuple, Union
+from typing import Any, Dict, List, Literal, Mapping, Optional, Set, Tuple, Union
 
 from pydantic import Field, root_validator
 from typing_extensions import Self
 
-from buildarr.config import ConfigEnum, NonEmptyStr, Password, Port, RemoteMapEntry
+from buildarr.config import RemoteMapEntry
+from buildarr.types import BaseEnum, NonEmptyStr, Password, Port
 
 from ..api import api_get, api_put
 from ..secrets import SonarrSecrets
 from .types import SonarrConfigBase
 
 
-class AuthenticationMethod(ConfigEnum):
+class AuthenticationMethod(BaseEnum):
     """
     Sonarr authentication method.
     """
@@ -44,7 +45,7 @@ class AuthenticationMethod(ConfigEnum):
     form = "forms"
 
 
-class CertificateValidation(ConfigEnum):
+class CertificateValidation(BaseEnum):
     """
     External site HTTPS certification validation method.
     """
@@ -54,7 +55,7 @@ class CertificateValidation(ConfigEnum):
     disabled = "disabled"
 
 
-class ProxyType(ConfigEnum):
+class ProxyType(BaseEnum):
     """
     Proxy server type.
     """
@@ -64,7 +65,7 @@ class ProxyType(ConfigEnum):
     socks5 = "socks5"
 
 
-class SonarrLogLevel(ConfigEnum):
+class SonarrLogLevel(BaseEnum):
     """
     Log level of the Sonarr application.
     """
@@ -74,7 +75,7 @@ class SonarrLogLevel(ConfigEnum):
     TRACE = "trace"
 
 
-class UpdateMechanism(ConfigEnum):
+class UpdateMechanism(BaseEnum):
     """
     Sonarr updating mechanism.
     """
@@ -147,7 +148,7 @@ class HostGeneralSettings(GeneralSettings):
 
     ssl_port: Port = 9898  # type: ignore[assignment]
     """
-    Enncrypted (HTTPS) listening port for Sonarr.
+    Encrypted (HTTPS) listening port for Sonarr.
 
     If Sonarr is being run via Docker in the default bridge mode,
     this setting shouldn't be changed.
@@ -341,7 +342,7 @@ class ProxyGeneralSettings(GeneralSettings):
     Only enter if authentication is required by the proxy.
     """
 
-    ignored_addresses: List[NonEmptyStr] = []
+    ignored_addresses: Set[NonEmptyStr] = set()
     """
     List of domains/addresses which bypass the proxy. Wildcards (`*`) are supported.
     """
@@ -378,9 +379,9 @@ class ProxyGeneralSettings(GeneralSettings):
             "proxyBypassFilter",
             {
                 "decoder": lambda v: (
-                    [addr.strip() for addr in v.split(",")] if v and v.strip() else []
+                    set(addr.strip() for addr in v.split(",")) if v and v.strip() else []
                 ),
-                "encoder": lambda v: ",".join(v),
+                "encoder": lambda v: ",".join(sorted(v)) if v else "",
             },
         ),
         ("bypass_proxy_for_local_addresses", "proxyBypassLocalAddresses", {}),
