@@ -24,17 +24,18 @@ from __future__ import annotations
 from typing import Any, Dict, List, Literal, Mapping, Optional, Set, Tuple, Type, Union
 
 from pydantic import Field, HttpUrl, PositiveInt
-from typing_extensions import Self
+from typing_extensions import Annotated, Self
 
-from buildarr.config import ConfigEnum, ConfigIntEnum, NonEmptyStr, Password, RemoteMapEntry, RssUrl
+from buildarr.config import RemoteMapEntry
 from buildarr.logging import plugin_logger
+from buildarr.types import BaseEnum, BaseIntEnum, NonEmptyStr, Password, RssUrl
 
 from ..api import api_delete, api_get, api_post, api_put
 from ..secrets import SonarrSecrets
 from .types import SonarrConfigBase
 
 
-class NabCategory(ConfigIntEnum):
+class NabCategory(BaseIntEnum):
     """
     Newznab/Torznab category enumeration.
     """
@@ -61,7 +62,7 @@ class NabCategory(ConfigIntEnum):
     # TV_DOCUMENTARY = "TV/Documentary"
 
 
-class FilelistCategory(ConfigEnum):
+class FilelistCategory(BaseEnum):
     """
     Filelist category enumeration.
     """
@@ -514,22 +515,40 @@ class FilelistIndexer(TorrentIndexer):
     as your API key will be sent to this host.
     """
 
-    categories: List[FilelistCategory] = [
+    categories: Set[FilelistCategory] = {
         FilelistCategory.TV_SD,
         FilelistCategory.TV_HD,
         FilelistCategory.TV_4K,
-    ]
+    }
     """
     Categories to monitor for standard/daily show new releases.
 
     Set to an empty list to not monitor for standard/daily shows.
+
+    Values:
+
+    * `Anime`
+    * `Animation`
+    * `TV 4K`
+    * `TV HD`
+    * `TV SD`
+    * `Sport`
     """
 
-    anime_categories: List[FilelistCategory] = []
+    anime_categories: Set[FilelistCategory] = set()
     """
     Categories to monitor for anime new releases.
 
     Leave empty to not monitor for anime.
+
+    Values:
+
+    * `Anime`
+    * `Animation`
+    * `TV 4K`
+    * `TV HD`
+    * `TV SD`
+    * `Sport`
     """
 
     _implementation = "FileList"
@@ -539,8 +558,16 @@ class FilelistIndexer(TorrentIndexer):
         ("username", "username", {"is_field": True}),
         ("passkey", "passKey", {"is_field": True}),
         ("api_url", "apiUrl", {"is_field": True}),
-        ("categories", "categories", {"is_field": True}),
-        ("anime_categories", "animeCategories", {"is_field": True}),
+        (
+            "categories",
+            "categories",
+            {"is_field": True, "encoder": lambda v: sorted(c.value for c in v)},
+        ),
+        (
+            "anime_categories",
+            "animeCategories",
+            {"is_field": True, "encoder": lambda v: sorted(c.value for c in v)},
+        ),
     ]
 
 
@@ -882,10 +909,26 @@ INDEXER_TYPES: Tuple[Type[Indexer], ...] = (
     TorrentleechIndexer,
     TorznabIndexer,
 )
+
 INDEXER_TYPE_MAP: Dict[str, Type[Indexer]] = {
     indexer_type._implementation: indexer_type for indexer_type in INDEXER_TYPES
 }
 
+IndexerType = Union[
+    FanzubIndexer,
+    NewznabIndexer,
+    OmgwtfnzbsIndexer,
+    BroadcasthenetIndexer,
+    FilelistIndexer,
+    HdbitsIndexer,
+    IptorrentsIndexer,
+    NyaaIndexer,
+    RarbgIndexer,
+    TorrentrssfeedIndexer,
+    TorrentleechIndexer,
+    TorznabIndexer,
+]
+
 
 class SonarrIndexersSettingsConfig(SonarrConfigBase):
     """
@@ -966,26 +1009,9 @@ class SonarrIndexersSettingsConfig(SonarrConfigBase):
     If unsure, leave set at the default of `false`.
     """
 
-    # TODO: Set minimum Python version to 3.11 and subscript INDEXER_TYPES here.
-    definitions: Dict[
-        str,
-        Union[
-            FanzubIndexer,
-            NewznabIndexer,
-            OmgwtfnzbsIndexer,
-            BroadcasthenetIndexer,
-            FilelistIndexer,
-            HdbitsIndexer,
-            IptorrentsIndexer,
-            NyaaIndexer,
-            RarbgIndexer,
-            TorrentrssfeedIndexer,
-            TorrentleechIndexer,
-            TorznabIndexer,
-        ],
-    ] = {}
+    definitions: Dict[str, Annotated[IndexerType, Field(discriminator="type")]] = {}
     """
-    Indexer to manage via Buildarr are defined here.
+    Indexers to manage via Buildarr are defined here.
     """
 
     _remote_map: List[RemoteMapEntry] = [
