@@ -23,6 +23,8 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from pydantic import ConstrainedStr
+
 from buildarr.config import ConfigBase
 
 if TYPE_CHECKING:
@@ -35,3 +37,12 @@ else:
 
     class SonarrConfigBase(ConfigBase):
         ...
+
+
+class TraktAuthUser(ConstrainedStr):
+    """
+    Constrained string type to make the Trakt auth user case-insensitive.
+    """
+
+    min_length = 1
+    to_lower = True
